// Generated by https://github.com/juliettef/IconFontCppHeaders script GenerateIconFontCppHeaders.py for language C++11
// from icons.yml
// for use with fa-brands-400.ttf
#pragma once

#define FONT_ICON_FILE_NAME_FAB "fa-brands-400.ttf"

#define ICON_MIN_FAB 0xe007
#define ICON_MAX_FAB 0xf8e8
#define ICON_FA_500PX u8"\uf26e"
#define ICON_FA_ACCESSIBLE_ICON u8"\uf368"
#define ICON_FA_ACCUSOFT u8"\uf369"
#define ICON_FA_ACQUISITIONS_INCORPORATED u8"\uf6af"
#define ICON_FA_ADN u8"\uf170"
#define ICON_FA_ADOBE u8"\uf778"
#define ICON_FA_ADVERSAL u8"\uf36a"
#define ICON_FA_AFFILIATETHEME u8"\uf36b"
#define ICON_FA_AIRBNB u8"\uf834"
#define ICON_FA_ALGOLIA u8"\uf36c"
#define ICON_FA_ALIPAY u8"\uf642"
#define ICON_FA_AMAZON u8"\uf270"
#define ICON_FA_AMAZON_PAY u8"\uf42c"
#define ICON_FA_AMILIA u8"\uf36d"
#define ICON_FA_ANDROID u8"\uf17b"
#define ICON_FA_ANGELLIST u8"\uf209"
#define ICON_FA_ANGRYCREATIVE u8"\uf36e"
#define ICON_FA_ANGULAR u8"\uf420"
#define ICON_FA_APP_STORE u8"\uf36f"
#define ICON_FA_APP_STORE_IOS u8"\uf370"
#define ICON_FA_APPER u8"\uf371"
#define ICON_FA_APPLE u8"\uf179"
#define ICON_FA_APPLE_PAY u8"\uf415"
#define ICON_FA_ARTSTATION u8"\uf77a"
#define ICON_FA_ASYMMETRIK u8"\uf372"
#define ICON_FA_ATLASSIAN u8"\uf77b"
#define ICON_FA_AUDIBLE u8"\uf373"
#define ICON_FA_AUTOPREFIXER u8"\uf41c"
#define ICON_FA_AVIANEX u8"\uf374"
#define ICON_FA_AVIATO u8"\uf421"
#define ICON_FA_AWS u8"\uf375"
#define ICON_FA_BANDCAMP u8"\uf2d5"
#define ICON_FA_BATTLE_NET u8"\uf835"
#define ICON_FA_BEHANCE u8"\uf1b4"
#define ICON_FA_BEHANCE_SQUARE u8"\uf1b5"
#define ICON_FA_BIMOBJECT u8"\uf378"
#define ICON_FA_BITBUCKET u8"\uf171"
#define ICON_FA_BITCOIN u8"\uf379"
#define ICON_FA_BITY u8"\uf37a"
#define ICON_FA_BLACK_TIE u8"\uf27e"
#define ICON_FA_BLACKBERRY u8"\uf37b"
#define ICON_FA_BLOGGER u8"\uf37c"
#define ICON_FA_BLOGGER_B u8"\uf37d"
#define ICON_FA_BLUETOOTH u8"\uf293"
#define ICON_FA_BLUETOOTH_B u8"\uf294"
#define ICON_FA_BOOTSTRAP u8"\uf836"
#define ICON_FA_BTC u8"\uf15a"
#define ICON_FA_BUFFER u8"\uf837"
#define ICON_FA_BUROMOBELEXPERTE u8"\uf37f"
#define ICON_FA_BUY_N_LARGE u8"\uf8a6"
#define ICON_FA_BUYSELLADS u8"\uf20d"
#define ICON_FA_CANADIAN_MAPLE_LEAF u8"\uf785"
#define ICON_FA_CC_AMAZON_PAY u8"\uf42d"
#define ICON_FA_CC_AMEX u8"\uf1f3"
#define ICON_FA_CC_APPLE_PAY u8"\uf416"
#define ICON_FA_CC_DINERS_CLUB u8"\uf24c"
#define ICON_FA_CC_DISCOVER u8"\uf1f2"
#define ICON_FA_CC_JCB u8"\uf24b"
#define ICON_FA_CC_MASTERCARD u8"\uf1f1"
#define ICON_FA_CC_PAYPAL u8"\uf1f4"
#define ICON_FA_CC_STRIPE u8"\uf1f5"
#define ICON_FA_CC_VISA u8"\uf1f0"
#define ICON_FA_CENTERCODE u8"\uf380"
#define ICON_FA_CENTOS u8"\uf789"
#define ICON_FA_CHROME u8"\uf268"
#define ICON_FA_CHROMECAST u8"\uf838"
#define ICON_FA_CLOUDSCALE u8"\uf383"
#define ICON_FA_CLOUDSMITH u8"\uf384"
#define ICON_FA_CLOUDVERSIFY u8"\uf385"
#define ICON_FA_CODEPEN u8"\uf1cb"
#define ICON_FA_CODIEPIE u8"\uf284"
#define ICON_FA_CONFLUENCE u8"\uf78d"
#define ICON_FA_CONNECTDEVELOP u8"\uf20e"
#define ICON_FA_CONTAO u8"\uf26d"
#define ICON_FA_COTTON_BUREAU u8"\uf89e"
#define ICON_FA_CPANEL u8"\uf388"
#define ICON_FA_CREATIVE_COMMONS u8"\uf25e"
#define ICON_FA_CREATIVE_COMMONS_BY u8"\uf4e7"
#define ICON_FA_CREATIVE_COMMONS_NC u8"\uf4e8"
#define ICON_FA_CREATIVE_COMMONS_NC_EU u8"\uf4e9"
#define ICON_FA_CREATIVE_COMMONS_NC_JP u8"\uf4ea"
#define ICON_FA_CREATIVE_COMMONS_ND u8"\uf4eb"
#define ICON_FA_CREATIVE_COMMONS_PD u8"\uf4ec"
#define ICON_FA_CREATIVE_COMMONS_PD_ALT u8"\uf4ed"
#define ICON_FA_CREATIVE_COMMONS_REMIX u8"\uf4ee"
#define ICON_FA_CREATIVE_COMMONS_SA u8"\uf4ef"
#define ICON_FA_CREATIVE_COMMONS_SAMPLING u8"\uf4f0"
#define ICON_FA_CREATIVE_COMMONS_SAMPLING_PLUS u8"\uf4f1"
#define ICON_FA_CREATIVE_COMMONS_SHARE u8"\uf4f2"
#define ICON_FA_CREATIVE_COMMONS_ZERO u8"\uf4f3"
#define ICON_FA_CRITICAL_ROLE u8"\uf6c9"
#define ICON_FA_CSS3 u8"\uf13c"
#define ICON_FA_CSS3_ALT u8"\uf38b"
#define ICON_FA_CUTTLEFISH u8"\uf38c"
#define ICON_FA_D_AND_D u8"\uf38d"
#define ICON_FA_D_AND_D_BEYOND u8"\uf6ca"
#define ICON_FA_DAILYMOTION u8"\ue052"
#define ICON_FA_DASHCUBE u8"\uf210"
#define ICON_FA_DEEZER u8"\ue077"
#define ICON_FA_DELICIOUS u8"\uf1a5"
#define ICON_FA_DEPLOYDOG u8"\uf38e"
#define ICON_FA_DESKPRO u8"\uf38f"
#define ICON_FA_DEV u8"\uf6cc"
#define ICON_FA_DEVIANTART u8"\uf1bd"
#define ICON_FA_DHL u8"\uf790"
#define ICON_FA_DIASPORA u8"\uf791"
#define ICON_FA_DIGG u8"\uf1a6"
#define ICON_FA_DIGITAL_OCEAN u8"\uf391"
#define ICON_FA_DISCORD u8"\uf392"
#define ICON_FA_DISCOURSE u8"\uf393"
#define ICON_FA_DOCHUB u8"\uf394"
#define ICON_FA_DOCKER u8"\uf395"
#define ICON_FA_DRAFT2DIGITAL u8"\uf396"
#define ICON_FA_DRIBBBLE u8"\uf17d"
#define ICON_FA_DRIBBBLE_SQUARE u8"\uf397"
#define ICON_FA_DROPBOX u8"\uf16b"
#define ICON_FA_DRUPAL u8"\uf1a9"
#define ICON_FA_DYALOG u8"\uf399"
#define ICON_FA_EARLYBIRDS u8"\uf39a"
#define ICON_FA_EBAY u8"\uf4f4"
#define ICON_FA_EDGE u8"\uf282"
#define ICON_FA_EDGE_LEGACY u8"\ue078"
#define ICON_FA_ELEMENTOR u8"\uf430"
#define ICON_FA_ELLO u8"\uf5f1"
#define ICON_FA_EMBER u8"\uf423"
#define ICON_FA_EMPIRE u8"\uf1d1"
#define ICON_FA_ENVIRA u8"\uf299"
#define ICON_FA_ERLANG u8"\uf39d"
#define ICON_FA_ETHEREUM u8"\uf42e"
#define ICON_FA_ETSY u8"\uf2d7"
#define ICON_FA_EVERNOTE u8"\uf839"
#define ICON_FA_EXPEDITEDSSL u8"\uf23e"
#define ICON_FA_FACEBOOK u8"\uf09a"
#define ICON_FA_FACEBOOK_F u8"\uf39e"
#define ICON_FA_FACEBOOK_MESSENGER u8"\uf39f"
#define ICON_FA_FACEBOOK_SQUARE u8"\uf082"
#define ICON_FA_FANTASY_FLIGHT_GAMES u8"\uf6dc"
#define ICON_FA_FEDEX u8"\uf797"
#define ICON_FA_FEDORA u8"\uf798"
#define ICON_FA_FIGMA u8"\uf799"
#define ICON_FA_FIREFOX u8"\uf269"
#define ICON_FA_FIREFOX_BROWSER u8"\ue007"
#define ICON_FA_FIRST_ORDER u8"\uf2b0"
#define ICON_FA_FIRST_ORDER_ALT u8"\uf50a"
#define ICON_FA_FIRSTDRAFT u8"\uf3a1"
#define ICON_FA_FLICKR u8"\uf16e"
#define ICON_FA_FLIPBOARD u8"\uf44d"
#define ICON_FA_FLY u8"\uf417"
#define ICON_FA_FONT_AWESOME u8"\uf2b4"
#define ICON_FA_FONT_AWESOME_ALT u8"\uf35c"
#define ICON_FA_FONT_AWESOME_FLAG u8"\uf425"
#define ICON_FA_FONT_AWESOME_LOGO_FULL u8"\uf4e6"
#define ICON_FA_FONTICONS u8"\uf280"
#define ICON_FA_FONTICONS_FI u8"\uf3a2"
#define ICON_FA_FORT_AWESOME u8"\uf286"
#define ICON_FA_FORT_AWESOME_ALT u8"\uf3a3"
#define ICON_FA_FORUMBEE u8"\uf211"
#define ICON_FA_FOURSQUARE u8"\uf180"
#define ICON_FA_FREE_CODE_CAMP u8"\uf2c5"
#define ICON_FA_FREEBSD u8"\uf3a4"
#define ICON_FA_FULCRUM u8"\uf50b"
#define ICON_FA_GALACTIC_REPUBLIC u8"\uf50c"
#define ICON_FA_GALACTIC_SENATE u8"\uf50d"
#define ICON_FA_GET_POCKET u8"\uf265"
#define ICON_FA_GG u8"\uf260"
#define ICON_FA_GG_CIRCLE u8"\uf261"
#define ICON_FA_GIT u8"\uf1d3"
#define ICON_FA_GIT_ALT u8"\uf841"
#define ICON_FA_GIT_SQUARE u8"\uf1d2"
#define ICON_FA_GITHUB u8"\uf09b"
#define ICON_FA_GITHUB_ALT u8"\uf113"
#define ICON_FA_GITHUB_SQUARE u8"\uf092"
#define ICON_FA_GITKRAKEN u8"\uf3a6"
#define ICON_FA_GITLAB u8"\uf296"
#define ICON_FA_GITTER u8"\uf426"
#define ICON_FA_GLIDE u8"\uf2a5"
#define ICON_FA_GLIDE_G u8"\uf2a6"
#define ICON_FA_GOFORE u8"\uf3a7"
#define ICON_FA_GOODREADS u8"\uf3a8"
#define ICON_FA_GOODREADS_G u8"\uf3a9"
#define ICON_FA_GOOGLE u8"\uf1a0"
#define ICON_FA_GOOGLE_DRIVE u8"\uf3aa"
#define ICON_FA_GOOGLE_PAY u8"\ue079"
#define ICON_FA_GOOGLE_PLAY u8"\uf3ab"
#define ICON_FA_GOOGLE_PLUS u8"\uf2b3"
#define ICON_FA_GOOGLE_PLUS_G u8"\uf0d5"
#define ICON_FA_GOOGLE_PLUS_SQUARE u8"\uf0d4"
#define ICON_FA_GOOGLE_WALLET u8"\uf1ee"
#define ICON_FA_GRATIPAY u8"\uf184"
#define ICON_FA_GRAV u8"\uf2d6"
#define ICON_FA_GRIPFIRE u8"\uf3ac"
#define ICON_FA_GRUNT u8"\uf3ad"
#define ICON_FA_GULP u8"\uf3ae"
#define ICON_FA_HACKER_NEWS u8"\uf1d4"
#define ICON_FA_HACKER_NEWS_SQUARE u8"\uf3af"
#define ICON_FA_HACKERRANK u8"\uf5f7"
#define ICON_FA_HIPS u8"\uf452"
#define ICON_FA_HIRE_A_HELPER u8"\uf3b0"
#define ICON_FA_HOOLI u8"\uf427"
#define ICON_FA_HORNBILL u8"\uf592"
#define ICON_FA_HOTJAR u8"\uf3b1"
#define ICON_FA_HOUZZ u8"\uf27c"
#define ICON_FA_HTML5 u8"\uf13b"
#define ICON_FA_HUBSPOT u8"\uf3b2"
#define ICON_FA_IDEAL u8"\ue013"
#define ICON_FA_IMDB u8"\uf2d8"
#define ICON_FA_INSTAGRAM u8"\uf16d"
#define ICON_FA_INSTAGRAM_SQUARE u8"\ue055"
#define ICON_FA_INTERCOM u8"\uf7af"
#define ICON_FA_INTERNET_EXPLORER u8"\uf26b"
#define ICON_FA_INVISION u8"\uf7b0"
#define ICON_FA_IOXHOST u8"\uf208"
#define ICON_FA_ITCH_IO u8"\uf83a"
#define ICON_FA_ITUNES u8"\uf3b4"
#define ICON_FA_ITUNES_NOTE u8"\uf3b5"
#define ICON_FA_JAVA u8"\uf4e4"
#define ICON_FA_JEDI_ORDER u8"\uf50e"
#define ICON_FA_JENKINS u8"\uf3b6"
#define ICON_FA_JIRA u8"\uf7b1"
#define ICON_FA_JOGET u8"\uf3b7"
#define ICON_FA_JOOMLA u8"\uf1aa"
#define ICON_FA_JS u8"\uf3b8"
#define ICON_FA_JS_SQUARE u8"\uf3b9"
#define ICON_FA_JSFIDDLE u8"\uf1cc"
#define ICON_FA_KAGGLE u8"\uf5fa"
#define ICON_FA_KEYBASE u8"\uf4f5"
#define ICON_FA_KEYCDN u8"\uf3ba"
#define ICON_FA_KICKSTARTER u8"\uf3bb"
#define ICON_FA_KICKSTARTER_K u8"\uf3bc"
#define ICON_FA_KORVUE u8"\uf42f"
#define ICON_FA_LARAVEL u8"\uf3bd"
#define ICON_FA_LASTFM u8"\uf202"
#define ICON_FA_LASTFM_SQUARE u8"\uf203"
#define ICON_FA_LEANPUB u8"\uf212"
#define ICON_FA_LESS u8"\uf41d"
#define ICON_FA_LINE u8"\uf3c0"
#define ICON_FA_LINKEDIN u8"\uf08c"
#define ICON_FA_LINKEDIN_IN u8"\uf0e1"
#define ICON_FA_LINODE u8"\uf2b8"
#define ICON_FA_LINUX u8"\uf17c"
#define ICON_FA_LYFT u8"\uf3c3"
#define ICON_FA_MAGENTO u8"\uf3c4"
#define ICON_FA_MAILCHIMP u8"\uf59e"
#define ICON_FA_MANDALORIAN u8"\uf50f"
#define ICON_FA_MARKDOWN u8"\uf60f"
#define ICON_FA_MASTODON u8"\uf4f6"
#define ICON_FA_MAXCDN u8"\uf136"
#define ICON_FA_MDB u8"\uf8ca"
#define ICON_FA_MEDAPPS u8"\uf3c6"
#define ICON_FA_MEDIUM u8"\uf23a"
#define ICON_FA_MEDIUM_M u8"\uf3c7"
#define ICON_FA_MEDRT u8"\uf3c8"
#define ICON_FA_MEETUP u8"\uf2e0"
#define ICON_FA_MEGAPORT u8"\uf5a3"
#define ICON_FA_MENDELEY u8"\uf7b3"
#define ICON_FA_MICROBLOG u8"\ue01a"
#define ICON_FA_MICROSOFT u8"\uf3ca"
#define ICON_FA_MIX u8"\uf3cb"
#define ICON_FA_MIXCLOUD u8"\uf289"
#define ICON_FA_MIXER u8"\ue056"
#define ICON_FA_MIZUNI u8"\uf3cc"
#define ICON_FA_MODX u8"\uf285"
#define ICON_FA_MONERO u8"\uf3d0"
#define ICON_FA_NAPSTER u8"\uf3d2"
#define ICON_FA_NEOS u8"\uf612"
#define ICON_FA_NIMBLR u8"\uf5a8"
#define ICON_FA_NODE u8"\uf419"
#define ICON_FA_NODE_JS u8"\uf3d3"
#define ICON_FA_NPM u8"\uf3d4"
#define ICON_FA_NS8 u8"\uf3d5"
#define ICON_FA_NUTRITIONIX u8"\uf3d6"
#define ICON_FA_ODNOKLASSNIKI u8"\uf263"
#define ICON_FA_ODNOKLASSNIKI_SQUARE u8"\uf264"
#define ICON_FA_OLD_REPUBLIC u8"\uf510"
#define ICON_FA_OPENCART u8"\uf23d"
#define ICON_FA_OPENID u8"\uf19b"
#define ICON_FA_OPERA u8"\uf26a"
#define ICON_FA_OPTIN_MONSTER u8"\uf23c"
#define ICON_FA_ORCID u8"\uf8d2"
#define ICON_FA_OSI u8"\uf41a"
#define ICON_FA_PAGE4 u8"\uf3d7"
#define ICON_FA_PAGELINES u8"\uf18c"
#define ICON_FA_PALFED u8"\uf3d8"
#define ICON_FA_PATREON u8"\uf3d9"
#define ICON_FA_PAYPAL u8"\uf1ed"
#define ICON_FA_PENNY_ARCADE u8"\uf704"
#define ICON_FA_PERISCOPE u8"\uf3da"
#define ICON_FA_PHABRICATOR u8"\uf3db"
#define ICON_FA_PHOENIX_FRAMEWORK u8"\uf3dc"
#define ICON_FA_PHOENIX_SQUADRON u8"\uf511"
#define ICON_FA_PHP u8"\uf457"
#define ICON_FA_PIED_PIPER u8"\uf2ae"
#define ICON_FA_PIED_PIPER_ALT u8"\uf1a8"
#define ICON_FA_PIED_PIPER_HAT u8"\uf4e5"
#define ICON_FA_PIED_PIPER_PP u8"\uf1a7"
#define ICON_FA_PIED_PIPER_SQUARE u8"\ue01e"
#define ICON_FA_PINTEREST u8"\uf0d2"
#define ICON_FA_PINTEREST_P u8"\uf231"
#define ICON_FA_PINTEREST_SQUARE u8"\uf0d3"
#define ICON_FA_PLAYSTATION u8"\uf3df"
#define ICON_FA_PRODUCT_HUNT u8"\uf288"
#define ICON_FA_PUSHED u8"\uf3e1"
#define ICON_FA_PYTHON u8"\uf3e2"
#define ICON_FA_QQ u8"\uf1d6"
#define ICON_FA_QUINSCAPE u8"\uf459"
#define ICON_FA_QUORA u8"\uf2c4"
#define ICON_FA_R_PROJECT u8"\uf4f7"
#define ICON_FA_RASPBERRY_PI u8"\uf7bb"
#define ICON_FA_RAVELRY u8"\uf2d9"
#define ICON_FA_REACT u8"\uf41b"
#define ICON_FA_REACTEUROPE u8"\uf75d"
#define ICON_FA_README u8"\uf4d5"
#define ICON_FA_REBEL u8"\uf1d0"
#define ICON_FA_RED_RIVER u8"\uf3e3"
#define ICON_FA_REDDIT u8"\uf1a1"
#define ICON_FA_REDDIT_ALIEN u8"\uf281"
#define ICON_FA_REDDIT_SQUARE u8"\uf1a2"
#define ICON_FA_REDHAT u8"\uf7bc"
#define ICON_FA_RENREN u8"\uf18b"
#define ICON_FA_REPLYD u8"\uf3e6"
#define ICON_FA_RESEARCHGATE u8"\uf4f8"
#define ICON_FA_RESOLVING u8"\uf3e7"
#define ICON_FA_REV u8"\uf5b2"
#define ICON_FA_ROCKETCHAT u8"\uf3e8"
#define ICON_FA_ROCKRMS u8"\uf3e9"
#define ICON_FA_RUST u8"\ue07a"
#define ICON_FA_SAFARI u8"\uf267"
#define ICON_FA_SALESFORCE u8"\uf83b"
#define ICON_FA_SASS u8"\uf41e"
#define ICON_FA_SCHLIX u8"\uf3ea"
#define ICON_FA_SCRIBD u8"\uf28a"
#define ICON_FA_SEARCHENGIN u8"\uf3eb"
#define ICON_FA_SELLCAST u8"\uf2da"
#define ICON_FA_SELLSY u8"\uf213"
#define ICON_FA_SERVICESTACK u8"\uf3ec"
#define ICON_FA_SHIRTSINBULK u8"\uf214"
#define ICON_FA_SHOPIFY u8"\ue057"
#define ICON_FA_SHOPWARE u8"\uf5b5"
#define ICON_FA_SIMPLYBUILT u8"\uf215"
#define ICON_FA_SISTRIX u8"\uf3ee"
#define ICON_FA_SITH u8"\uf512"
#define ICON_FA_SKETCH u8"\uf7c6"
#define ICON_FA_SKYATLAS u8"\uf216"
#define ICON_FA_SKYPE u8"\uf17e"
#define ICON_FA_SLACK u8"\uf198"
#define ICON_FA_SLACK_HASH u8"\uf3ef"
#define ICON_FA_SLIDESHARE u8"\uf1e7"
#define ICON_FA_SNAPCHAT u8"\uf2ab"
#define ICON_FA_SNAPCHAT_GHOST u8"\uf2ac"
#define ICON_FA_SNAPCHAT_SQUARE u8"\uf2ad"
#define ICON_FA_SOUNDCLOUD u8"\uf1be"
#define ICON_FA_SOURCETREE u8"\uf7d3"
#define ICON_FA_SPEAKAP u8"\uf3f3"
#define ICON_FA_SPEAKER_DECK u8"\uf83c"
#define ICON_FA_SPOTIFY u8"\uf1bc"
#define ICON_FA_SQUARESPACE u8"\uf5be"
#define ICON_FA_STACK_EXCHANGE u8"\uf18d"
#define ICON_FA_STACK_OVERFLOW u8"\uf16c"
#define ICON_FA_STACKPATH u8"\uf842"
#define ICON_FA_STAYLINKED u8"\uf3f5"
#define ICON_FA_STEAM u8"\uf1b6"
#define ICON_FA_STEAM_SQUARE u8"\uf1b7"
#define ICON_FA_STEAM_SYMBOL u8"\uf3f6"
#define ICON_FA_STICKER_MULE u8"\uf3f7"
#define ICON_FA_STRAVA u8"\uf428"
#define ICON_FA_STRIPE u8"\uf429"
#define ICON_FA_STRIPE_S u8"\uf42a"
#define ICON_FA_STUDIOVINARI u8"\uf3f8"
#define ICON_FA_STUMBLEUPON u8"\uf1a4"
#define ICON_FA_STUMBLEUPON_CIRCLE u8"\uf1a3"
#define ICON_FA_SUPERPOWERS u8"\uf2dd"
#define ICON_FA_SUPPLE u8"\uf3f9"
#define ICON_FA_SUSE u8"\uf7d6"
#define ICON_FA_SWIFT u8"\uf8e1"
#define ICON_FA_SYMFONY u8"\uf83d"
#define ICON_FA_TEAMSPEAK u8"\uf4f9"
#define ICON_FA_TELEGRAM u8"\uf2c6"
#define ICON_FA_TELEGRAM_PLANE u8"\uf3fe"
#define ICON_FA_TENCENT_WEIBO u8"\uf1d5"
#define ICON_FA_THE_RED_YETI u8"\uf69d"
#define ICON_FA_THEMECO u8"\uf5c6"
#define ICON_FA_THEMEISLE u8"\uf2b2"
#define ICON_FA_THINK_PEAKS u8"\uf731"
#define ICON_FA_TIKTOK u8"\ue07b"
#define ICON_FA_TRADE_FEDERATION u8"\uf513"
#define ICON_FA_TRELLO u8"\uf181"
#define ICON_FA_TRIPADVISOR u8"\uf262"
#define ICON_FA_TUMBLR u8"\uf173"
#define ICON_FA_TUMBLR_SQUARE u8"\uf174"
#define ICON_FA_TWITCH u8"\uf1e8"
#define ICON_FA_TWITTER u8"\uf099"
#define ICON_FA_TWITTER_SQUARE u8"\uf081"
#define ICON_FA_TYPO3 u8"\uf42b"
#define ICON_FA_UBER u8"\uf402"
#define ICON_FA_UBUNTU u8"\uf7df"
#define ICON_FA_UIKIT u8"\uf403"
#define ICON_FA_UMBRACO u8"\uf8e8"
#define ICON_FA_UNIREGISTRY u8"\uf404"
#define ICON_FA_UNITY u8"\ue049"
#define ICON_FA_UNSPLASH u8"\ue07c"
#define ICON_FA_UNTAPPD u8"\uf405"
#define ICON_FA_UPS u8"\uf7e0"
#define ICON_FA_USB u8"\uf287"
#define ICON_FA_USPS u8"\uf7e1"
#define ICON_FA_USSUNNAH u8"\uf407"
#define ICON_FA_VAADIN u8"\uf408"
#define ICON_FA_VIACOIN u8"\uf237"
#define ICON_FA_VIADEO u8"\uf2a9"
#define ICON_FA_VIADEO_SQUARE u8"\uf2aa"
#define ICON_FA_VIBER u8"\uf409"
#define ICON_FA_VIMEO u8"\uf40a"
#define ICON_FA_VIMEO_SQUARE u8"\uf194"
#define ICON_FA_VIMEO_V u8"\uf27d"
#define ICON_FA_VINE u8"\uf1ca"
#define ICON_FA_VK u8"\uf189"
#define ICON_FA_VNV u8"\uf40b"
#define ICON_FA_VUEJS u8"\uf41f"
#define ICON_FA_WAZE u8"\uf83f"
#define ICON_FA_WEEBLY u8"\uf5cc"
#define ICON_FA_WEIBO u8"\uf18a"
#define ICON_FA_WEIXIN u8"\uf1d7"
#define ICON_FA_WHATSAPP u8"\uf232"
#define ICON_FA_WHATSAPP_SQUARE u8"\uf40c"
#define ICON_FA_WHMCS u8"\uf40d"
#define ICON_FA_WIKIPEDIA_W u8"\uf266"
#define ICON_FA_WINDOWS u8"\uf17a"
#define ICON_FA_WIX u8"\uf5cf"
#define ICON_FA_WIZARDS_OF_THE_COAST u8"\uf730"
#define ICON_FA_WOLF_PACK_BATTALION u8"\uf514"
#define ICON_FA_WORDPRESS u8"\uf19a"
#define ICON_FA_WORDPRESS_SIMPLE u8"\uf411"
#define ICON_FA_WPBEGINNER u8"\uf297"
#define ICON_FA_WPEXPLORER u8"\uf2de"
#define ICON_FA_WPFORMS u8"\uf298"
#define ICON_FA_WPRESSR u8"\uf3e4"
#define ICON_FA_XBOX u8"\uf412"
#define ICON_FA_XING u8"\uf168"
#define ICON_FA_XING_SQUARE u8"\uf169"
#define ICON_FA_Y_COMBINATOR u8"\uf23b"
#define ICON_FA_YAHOO u8"\uf19e"
#define ICON_FA_YAMMER u8"\uf840"
#define ICON_FA_YANDEX u8"\uf413"
#define ICON_FA_YANDEX_INTERNATIONAL u8"\uf414"
#define ICON_FA_YARN u8"\uf7e3"
#define ICON_FA_YELP u8"\uf1e9"
#define ICON_FA_YOAST u8"\uf2b1"
#define ICON_FA_YOUTUBE u8"\uf167"
#define ICON_FA_YOUTUBE_SQUARE u8"\uf431"
#define ICON_FA_ZHIHU u8"\uf63f"
